#
# spec file for mp3plot rpm
#
# originally based on
#   <http://kmymoney2.sourceforge.net/phb/rpm-example.html>
# automake stuff (i.e. @whatever@) from
#   <http://www.shlomifish.org/lecture/Autotools/slides/issues/rpm-spec.html>
#   fields like @SOMETHING@ will be replaced by ./configure
# Fedora/Red Hat/RHEL stuff from
#   <http://fedoraproject.org/wiki/Packaging/DistTag>
#   TODO: Which other distros have adopted the Red Hat way, and which tags do they use?

%define is_mandrake %(test -e /etc/mandrake-release && echo 1 || echo 0)
%define is_suse %(test -e /etc/SuSE-release && echo 1 || echo 0)
%define is_fedora 0%{?fedora}
%define is_redhat 0%{?rhl}
%define is_rhel 0%{?rhel}

%define distname generic
%define disttag .generic_lsb

%if %{is_fedora}
%define distname fedora
%define disttag %{dist}
%endif
%if %{is_redhat}
%define distname redhat
%define disttag %{dist}
%endif
%if %{is_mandrake}
%define distname mandrake
%define disttag .mdk
%endif
%if %{is_suse}
%define distname suse
%define disttag .suse
%endif
%if %{is_rhel}
%define distname rhel
%define disttag %{dist}
%endif

# i386 shouldn't be used as arch, build will fail with a
#  "undefined reference: ... __sync_fetch_and_add_4"
#  <http://sources.redhat.com/ml/libc-alpha/2007-02/msg00009.html>
# This shouldn't be a problem on real RPM distros
%define optflags_ %(echo "%{optflags}" | sed -r 's/(mtune|mcpu)=i386/\1=i486/g')

#%define distver %(release="`rpm -q --queryformat='%{VERSION}' %{distname}-release 2> /dev/null | tr . : | sed s/://g`" ; if test $? != 0 ; then release="" ; fi ; echo "$release")

# Only set packager if empty
%if %(test "%{packager}" == "" && echo 1 || echo 0)
%define packager %(finger -lp `echo $USER` | head -n1 | cut -d: -f3)
%endif

Name: mp3plot
Summary: MP3 bitrate analysis tool
Version: 0.6.0
Release: 1%{?disttag}~upstream
License: GPL
#Vendor: Toni Corvera
Packager: %packager
Group: Applications/Audio
Source0: http://p.outlyer.net/%{name}/files/%{name}-%{version}.tar.gz
#Source0: %{name}-%version.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-build
URL: http://p.outlyer.net/mp3plot
#BuildRequires:
#Prereq: /sbin/ldconfig
#Requires:
AutoReqProv: yes
## Allow relocation (e.g. rpm --prefix /opt/mp3plot)
Prefix: /usr

%description
mp3plot creates a plot (textual or graphical) of the bitrate distribution of
an MP3 file; i.e. it displays which proportion of the audio file uses
each of the possible bitrates.

The plot can serve e.g. to compare an audio source as encoded by different
encoders or settings; or to display how the chosen (average) bitrate was
achieved by the encoder.


%prep
#echo %_target
echo Building %{name}-%{version}-%{release}

%setup -q -n %{name}-%{version}

%build
CXXFLAGS="%{optflags_}" ./configure --prefix=%{_prefix} --enable-gd --disable-magick
make

%install
make DESTDIR=%buildroot install

%clean
[ ${RPM_BUILD_ROOT} != "/" ] && rm -rf ${RPM_BUILD_ROOT}

#%post
# postinst

#%postun
# postuninst

%files
%defattr(-,root,root)
# binary
%{_bindir}/%{name}
# Manpage
%{_mandir}/man1/%{name}.1.gz
%doc README

%changelog
* Mon Jun 22 2009 - outlyer (at) gmail (dot) com
- New version

* Sat Apr 25 2009 - outlyer (at) gmail (dot) com
- New version

* Fri Apr 10 2009 - outlyer (at) gmail (dot) com
- Initial RPM packaging

