/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: errors.h 1341 2009-06-21 02:49:59Z toni $

#ifndef MP3PLOT_ERRORS_H
#define MP3PLOT_ERRORS_H

#include <string>
#include <ostream>

#include "mp3_config.h"

namespace mp3plot {

    // Forward declaration for documentation purposes
    class e_error;

    //! Generic error
    class e_error : public std::exception {
    public:
        e_error(const std::string& s, int errcode = EX_SOFTWARE)
            : std::exception(), error_code(errcode), msg(s)
        {}

        e_error()
            : std::exception(), error_code(EX_SOFTWARE), msg("Undefined internal error")
        {}

        e_error(const e_error & E)
            : std::exception(), error_code(E.error_code), msg(E.msg)
        {}

        // G++ requires this definition
        virtual ~e_error() throw() {}

        virtual const char* what() const throw() {
            return msg.c_str();
        }

        const int error_code;
    private:
        const std::string msg;
    };

    class e_read_failure : public e_error {
        public:
            e_read_failure(const std::string & msg, int errcode = EX_IOERR)
                : e_error(msg, errcode) {}

            e_read_failure()
                : e_error("Failed to read data.", EX_IOERR) {}
    };

    struct e_bad_filetype : public e_error {
        public:
            e_bad_filetype()
                : e_error("Unsupported file format.", EX_DATAERR)
            {}
        protected:
            e_bad_filetype(const std::string & m, const int errcode = EX_DATAERR)
                : e_error(m, errcode)
            {}
    };

} // namespace mp3plot

#endif // MP3PLOT_ERRORS_H
// vim:set ts=4 et ai:

