/*
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: macros.h 1150 2009-04-14 02:21:18Z  $

#ifndef MP3PLOT_MACROS_H
#define MP3PLOT_MACROS_H

/*!
 * \file
 * This file defines stuff that can only be done through the
 * preprocessor.
 */

/*!
 * \brief Disables compiler warnings (in known compilers) about variables
 *        unused on purpose (e.g. in "concepts").
 */
// References of interest:
// <http://sourcefrog.net/weblog/software/languages/C/unused.html>
#ifndef UNUSED_
#   ifdef __GNUC__
#       define UNUSED_      __attribute__((unused))
#       define DEPRECATED_  __attribute__((deprecated))
#   // MSVC (_MSC_VER) doesn't seem to have an unused attribute (__declspec(...))
#   else
#       define UNUSED_      
#   endif
#endif
// Extended attributes references & info:
// <http://www.keil.com/support/man/docs/armccref/armccref_cjadeajc.htm>
//      (ARM compiler) declspec
// <http://www.keil.com/support/man/docs/armccref/armccref_chdfijae.htm>
//      (ARM compiler) vendor features, incl. __attribute__
// <http://www.usenix.org/publications/login/2008-02/openpdfs/standards0208.pdf>

// Preferred name for "NULL" in C++, will be in C++0x
#ifndef nullptr
#   define nullptr  0
#endif

// Not used right now
#define NOINLINE_
#define NOEXPORT_

#endif // MP3PLOT_MACROS_H

// vim:set ts=4 et ai:
