/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: element.h 1148 2009-04-14 02:10:48Z  $

#ifndef MP3PLOT_MP3_ELEMENT_H
#define MP3PLOT_MP3_ELEMENT_H

#include <fstream>
#include <string>

#include "../errors.h"

namespace mp3plot {

/*!
 * \brief Lower level namespace, contains classes related to raw reading of mp3 files.
 */
namespace mp3 {

    /*!
     * \brief Abstraction of an mp3 element (frame or tag).
     */
    class element {
    public:
        virtual ~element() {};

        /*!
         * \brief Read element's data.
         * Implementors should obtain their data in the implementation of this method.
         * \param input The input file
         * \throw e_error If a read error occurs
         */
        virtual void read(std::ifstream & input) throw (e_error) = 0;

    protected:
        element() {}

        /*!
         * \brief Tests if the input is ok to continue reading
         * \throws e_read_failure if can't read further.
         * \param input The input file
         * \param failed_on Context of the check. It will be used to construct
         * the error message.
         */
        static void check(const std::ifstream & input,
                          const std::string & failed_on="data")
                                                       throw (e_read_failure);
    };

} // namespace mp3

} // namespace mp3plot

#endif // MP3PLOT_MP3_ELEMENT_H
// vim:set ts=4 et ai:

