/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: tags.cc 1101 2009-04-05 17:33:40Z  $

#include "tags.h"
#include "../utils/str_utils.h"
#include "../mp3_config.h" // btoh16

#include <iostream>
#include <cstring> // memcmp, memcpy

using std::string;
using std::ifstream;
using std::cout;

namespace str = net_outlyer::str;

namespace mp3plot {

namespace mp3 {

    using net_outlyer::btoh16;

// -- ID3v2 Header --

void id3v2tag::read(ifstream & in) throw (e_read_failure) {
    in.read(CHARR(id), 3);
    check(in, "header");

    if (0 != ::memcmp("ID3", CHARR(id), 3)) {
        // Tried to read an ID3v2 tag from a file without it
        throw e_bad_filetype();
    }
    // POST ]-> It looks like a valid file

    in.read(CHARR(version), 2);
    check(in, "header");
    in.read(CHARR(&flags), 1);
    check(in, "header");
    //in.read(CHARR(&tag_size), 4);
    //if (!in.good()) throw 1;
    {
        tag_size = 0;
        for (int i=0; i<4; ++i) {
            uint8_t byte;
            in.read(CHARR(&byte), 1);
            // FIXME: probably incorrect for more than 2 bytes!
            tag_size = (tag_size << 7) + (byte & 0x7f);
        }
    }
}

std::ostream & operator<<(std::ostream & os, const id3v2tag & t) {
    string sid;

    {
        char buffer[4];
        ::memcpy(buffer, t.id, 3);
        buffer[3] = 0;
        sid = buffer;
    }

    os << "Tag Identifier / File Magic: " << sid << "\n";
    os << "Tag version: " << str::to_hex(btoh16(* t.version),2,true) << "\n";
    os << "ID3V2 Flags: " << str::to_hex(t.flags,1,true) << "\n";
    os << "Tag size: " << t.tag_size << std::endl;

    return os;
}

// -- ID3v1 Header --

void id3v1tag::read(ifstream & in) throw (e_read_failure) {
}

} // namespace mp3

} // namespace mp3plot

// vim:set ts=4 et ai:

