//#! cscript upd.js

// $Id: make_winconfig.js 1343 2009-06-22 00:09:32Z toni $

$CONFIGURE_AC = "../../configure.ac";
$OUTPUT="winconfig.h"
RW=-1;
RO=1;

_INCREMENTAL_EXIT_CODE__ = 1;
/*
 * [1] http://www.wilsonmar.com/1wsh.htm
 * [2] MSDN: FileSystemObject
 *         <http://msdn.microsoft.com/en-us/library/6kxy1a51(VS.85).aspx>
 */
// Notes to self:
//   Exit code can be checked with > echo %errorlevel%

function fine(msg) {
    WScript.Echo(msg);
}
function error(msg) {
    WScript.Echo("ERROR: " + msg);
}
function warn(msg) {
    WScript.Echo("Warning: " + msg);
}

function getTextFileOrDie(filename, mode, exitCode) {
    if (null == mode) { mode = RO; }
    if (null == exitCode) { exitCode = _INCREMENTAL_EXIT_CODE__++; }
    var f;
    try {
        switch (mode) {
            case RO: f = fso.OpenTextFile(filename, mode); break;
            case RW: f = fso.CreateTextFile(filename); break;
            default: throw new Error("Unsupported operation");
        }
    }
    catch (e) {
        var operror;
        if (mode == RO || mode == RW) {
            operror = ("Failed to ") + ( (mode == RO) ? "open" : "create" );
        }
        else {
            operror = "While handling ";
        }
        error(operror+" "+filename+":\n\t"+e.description);
        WScript.Quit(exitCode);
    }
    return f;
}

var fso = new ActiveXObject("Scripting.FileSystemObject");
var acfile, ac, e;

fine("Opening configure.ac file (looking in "+$CONFIGURE_AC+")...");
acfile = getTextFileOrDie($CONFIGURE_AC);
try {
    fine("Reading contents of file...");
    var ac = acfile.ReadAll();
}
catch (e) { // Can it throw?
    error("Failed to read "+$CONFIGURE_AC+":\n\t"+e.description);
    WScript.Quit(4);
}
acfile.Close();

var $VERSION;

fine("Trying to extract values for definitions...");
var vermatcher = /AC_INIT\(\[?(.*?)\]?, \[?([\w\.]+)\]?/;
var match = vermatcher.exec(ac);
if (null == match) {
    warn("None found");
}
else {
    $PACKAGE = match[1];
    $VERSION = match[2];
}

var defmatcher = /^AC_DEFINE\(\[?([^\],]+)\]?\s*,\s*\[?([^\]]+)\]?\s*,\s*\[?([^\]]+)\]?\)/m;
var defines = new String();
var offset = 0;
do {
    var s = ac.substr(offset);
    match = s.match(defmatcher);
    if (null == match) {
        break;
    }
    offset += match.lastIndex;
    defines += '#define '+match[1]+'\t'+match[2]+' // '+match[3]+'\n';
}
while (1);

var output =
    "#define PACKAGE         \""+$PACKAGE+"\"\n"+
    "#define VERSION         \""+$VERSION+"\"\n"+
    "#define PACKAGE_NAME    \""+$PACKAGE+"\"\n"+
    "#define PACKAGE_VERSION \""+$VERSION+"\"\n"+
    "#define PACKAGE_STRING  \""+$PACKAGE+" "+$VERSION+"\"\n"+
    "#define PACKAGE_TARNAME \""+$PACKAGE+"\"\n"
    +defines;
;

// Extra shell variables defined in configure.ac
var extm=/(AUTHOR|UPSTREAM_URL)="?(.*)"?$/m;
offset = 0;
do {
    var s = ac.substr(offset);
    match = s.match(extm);
    if (null == match) {
        break;
    }
    offset += match.lastIndex;
    
    // Simplified regexp above; this adds quotes as required
    var value = match[2];
    if (0 != value.indexOf('"')) {
        value = '"'+value;
    }
    if ((value.length-1) != value.lastIndexOf('"')) {
        value += '"';
    }
    output += "#define "+match[1]+" "+value+"\n";
} while (true);

// Try to parse find the revision
var revm = /AC_REVISION\((.*?)\)/;
var rev = "";
match = revm.exec(ac);
if (null != match) {
    rev = " * Source configure.ac revision: "+match[1]+"\n";
}

WScript.Echo("Output:\n"+output);

fine("Writing output to "+$OUTPUT+"...");
var ofh = getTextFileOrDie($OUTPUT, RW);

ofh.write(
    "/*\n"+
    " * This file was generated automatically on "+new Date()+"\n"+
    " * from the autoconf input of "+$PACKAGE+" using the provided\n"+
    " * script for the \"Windows Script Host\". Systems other than\n"+
    " * Windows have no need for this file or the aforementioned script\n"+
    rev+
    " */\n"+
    output+
    "\n"+
    "#include \"winconfig.inc.h\"\n"
);

ofh.Close();
WScript.Quit(0);