/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/*!
 * \file
 * \brief Windows dependencies configuration.
 *
 * This file provides default definitions of available features for
 * compilation with Microsoft Visual C++.
 * It is meant to be included by winconfig.h, which in turn is meant
 * to be automatically generated by make_winconfig.js.
 *
 * Unlike when using autotools, no detection of libraries is made,
 * all requirements are assumed to be available.
 */

// Windows-specific stuff
#if defined(_WIN32) || defined(_WIN64) // Win64 is untested, but *should* work

#if 0
#   ifdef _MSC_VER
//  temporarily disable the "macro redefinition message"
#       pragma warning ( disable : 4005 )
#   endif
#endif

///////////////////////////////////////////////////////////////////////////////
// Optional Libraries, redefine if required by the build system
///////////////////////////////////////////////////////////////////////////////

#define HAVE_GD 1
#undef HAVE_MAGICKPP
#undef HAVE_GRAPHICSMAGICKPP
#undef HAVE_IMAGEMAGICKPP

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//        ---- NO MANUAL EDITING TO CONFIGURE BEYOND THIS POINT ----         //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// Required Headers
///////////////////////////////////////////////////////////////////////////////

#ifdef _MSCVER
// No inttypes nor stdint are provided in MSVC, they are supplied in the
// src/msvc directory
#   define HAVE_INTTYPES_H 1
#   define HAVE_STDINT_H 1
#pragma message("Hello World")
#endif

// C include files, should be provided
#define STDC_HEADERS 1
#define HAVE_MEMORY_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STRING_H 1
#define HAVE_SYS_TYPES_H 1

// POSIX & pals includes
#undef HAVE_SYSEXITS_H

///////////////////////////////////////////////////////////////////////////////
// Required Libraries
///////////////////////////////////////////////////////////////////////////////

#define HAVE_BOOST 
#define HAVE_BOOST_PROGRAM_OPTIONS 
#define HAVE_BOOST_THREAD 
//#define HAVE_BOOST_SHARED_PTR_HPP // Not needed anymore
//#undef HAVE_TR1_MEMORY // Not neded anymore. No support for TR1 in MSVC yet

///////////////////////////////////////////////////////////////////////////////
// Deduced from the above
///////////////////////////////////////////////////////////////////////////////

#ifdef HAVE_GD
#   define HAVE_GDFONTL_H 1
#   define HAVE_GD_H 1
#endif

#if defined(HAVE_GD) || defined(HAVE_MAGICKPP)
#   define HAVE_GRAPHICS_SUPPORT 1
#endif

///////////////////////////////////////////////////////////////////////////////
// Compiler-specific stuff
///////////////////////////////////////////////////////////////////////////////

#ifdef _MSC_VER
// Disable warnings about exception specification ( fn() throw(...) )
// Ref: <http://msdn.microsoft.com/en-us/library/sa28fef8.aspx>
#   pragma warning ( disable : 4290 )
#endif

#else
#   error This file should only be included in Windows systems
#endif // windows
// vim:set ts=4 et ai: //
