/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: bitrate_plotter.cc 1128 2009-04-10 01:31:58Z  $

#include <algorithm>

#include "bitrate_plotter.h"
#include "../mp3_file.h"
#include "../utils/str_utils.h"

namespace mp3plot {

namespace str = net_outlyer::str;
using namespace std;

    // [C++]
    // Note at some point I tried using local classes instead of these but
    // G++ (4.3) didn't like it too much, whereas MSVC 9.0 worked fine.
    // Not that one method is much more readble than the other though...

    template<typename T_> struct predicate {
    public:
        predicate(const T_ & tval)
            : tval_(tval)
        {}
    protected:
        const T_ & tval_;
    };

    struct matches_features : public predicate<plotter_features> {
        matches_features(const plotter_features & pf)
            : predicate<plotter_features>(pf)
        {}

        bool operator () (bitrate_plotter::wrapper_type & brp) {
            return brp->description().matches_features( tval_ );
        }
    };

    struct includes_features : public predicate<plotter_features> {
        includes_features(const plotter_features & pd)
            : predicate<plotter_features>(pd)
        {}

        bool operator () (bitrate_plotter::wrapper_type & brp) {
            return brp->description().includes_features( tval_ );
        }
    };

    struct matches_name : public predicate<std::string> {
        matches_name(const std::string & n)
            : predicate<std::string>(n)
        {}

        bool operator() (bitrate_plotter::wrapper_type & brp) {
            return brp->description().name() == tval_;
        }
    };

// static member definition
bitrate_plotter::plotters_type bitrate_plotter::plotters;

template<typename Predicate, typename ExceptionType>
 inline bitrate_plotter & choose_impl(Predicate p) throw (ExceptionType)
{
    bitrate_plotter::plotters_type::iterator I =
                                std::find_if(bitrate_plotter::plotters.begin(),
                                             bitrate_plotter::plotters.end(),
                                             p);
    if (bitrate_plotter::plotters.end() == I) {
        throw ExceptionType();
    }

    return **I;
}

// static
bitrate_plotter & bitrate_plotter::choose(const plotter_features & f)
    throw (e_unregistered_plotter_type)
{
    return choose_impl<matches_features, e_unregistered_plotter_type>
                        (matches_features(f));
}

// static
bitrate_plotter & bitrate_plotter::choose(const std::string & name)
    throw (e_no_plotter_matches_name)
{
    return choose_impl<matches_name, e_no_plotter_matches_name>
                        (matches_name(name));
}

// static
bitrate_plotter & bitrate_plotter::choose_fuzzy(const plotter_features & f)
    throw (e_unregistered_plotter_type)
{
    return choose_impl<includes_features, e_unregistered_plotter_type>
                        (includes_features(f));
}

vector<string> bitrate_plotter::list() {
    vector<string> v(0);
    v.reserve(plotters.size());

    for (plotters_type::const_iterator it = plotters.begin();
         it != plotters.end();
         ++it)
    {
        v.push_back( str::to_string((*it)->description()) );
    }

    return v;
}

} // namespace mp3plot

// vim:set ts=4 et ai:

