/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
// $Id: graphics_lib_interface.h 1146 2009-04-14 01:53:01Z  $ //

#ifndef MP3PLOT_GRAPHICS_LIB_INTERFACE_H
#define MP3PLOT_GRAPHICS_LIB_INTERFACE_H

#include <string>
#include "colour.h"

namespace mp3plot {

/*!
 * \brief Wrapper interface/abstraction around graphics libraries.
 * \remarks Not meant as a general abstraction, only wrapper methods required by
 *          mp3plot are defined.
 */
template<typename ImageType, typename ColourType>
struct graphics_lib_interface {
    typedef ImageType                           image_type;
    typedef ColourType                          native_colour;
    typedef net_outlyer::colour_type<double,1>  common_colour;

    virtual image_type create_image(int w, int h) const = 0;
    virtual void resize(image_type &, int w, int h) const = 0;
    virtual image_type vertical_merge(const image_type&, const image_type&) const = 0;
    virtual native_colour allocate_colour(image_type&, const common_colour&) const = 0;

    virtual void draw_line(image_type &, int x0, int y0, int x1, int y1, const native_colour&) const = 0;
    virtual void draw_rectangle(image_type&, int x0, int y0, int x1, int y1, const native_colour&) const = 0;
    virtual void draw_text(image_type&, int x, int y, const native_colour&, const std::string&) const = 0;
};

} // ns mp3plot

#endif /* MP3PLOT_GRAPHICS_LIB_INTERFACE_H */

