/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: init_plotters.h 1113 2009-04-09 01:33:39Z  $

/*!
 * \file
 * This file contains initialization code for the mp3 modules
 */

#ifndef MP3PLOT_INIT_H
#define MP3PLOT_INIT_H

#include "mp3_config.h"

#include "plotters/bitrate_plotter.h"
#include "plotters/console_plotter.h"

#ifdef HAVE_MAGICKPP
#   include <Magick++.h>
#endif

#ifdef HAVE_MAGICKPP
#   include "plotters/magickpp_plotter.h"
#endif

#ifdef HAVE_MAGICK
#   include "plotters/mp3_magick_plotter.h"
#endif

#ifdef HAVE_GD
#   include "plotters/gd_plotter.h"
#endif

namespace mp3plot {

/*!
 * \brief Registers the available plotters
 */
inline void register_plotters(const char * const progname) {
    bitrate_plotter::register_plotter<console_plotter>();

#ifndef DISABLE_GRAPHICS

#if defined(HAVE_MAGICKPP) && !defined(DISABLE_MAGICKPP)
    // ImageMagick++ requires initialization in some OSes
    // see <http://www.imagemagick.org/Magick++/>
    Magick::InitializeMagick(progname);
    bitrate_plotter::register_plotter<magickpp_plotter>();
#endif

#if defined(HAVE_MAGICK) && !defined(DISABLE_MAGICK)
    bitrate_plotter::register_plotter<magick_plotter>();
#endif // Magick

#if defined(HAVE_GD) && !defined(DISABLE_GD)
    bitrate_plotter::register_plotter<gd_plotter>();
#endif // GD

#endif // DISABLE_GRAPHICS
}

} // namespace mp3plot

#endif // MP3PLOT_INIT_H
// vim:set ts=4 et ai:

