/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: old_colourscheme.inc.cc 1345 2009-06-22 01:27:48Z toni $
// Old colourscheme, used up to version 0.5.0

#include "../common.h"
#include "../mp3/bitrate.h"
#include "colour.h"

#include <cassert>
#include <vector>
#include <map>

#include <iostream>

namespace mp3plot {
namespace impl {
namespace old_colourscheme {

using namespace std;
using namespace net_outlyer;

const map<uint8_t, rgb_type>& get_map() {
	static map<uint8_t, rgb_type> m;

	if (m.empty()) {
		typedef colour_type<int, 255> ict;
		uint8_t header_idx = 0;
		// Free-form
		m.insert( make_pair(0, rgb_type(0,0,.3L)) );

		// Standard bitrates
		// 32-56: r=0, g=0
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,0,.4L)) ); // 32
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,0,.5L)) ); // 40
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,0,.6L)) ); // 48
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,0,.7L)) ); // 56
		// 64-128: r=0, b=0
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,.3L,0)) ); // 64
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,.4L,0)) ); // 80
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,.5L,0)) ); // 96
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,.6L,0)) ); // 112
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(0,.7L,0)) ); // 128
		// 160-320: g=0, b=0
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(.3L,0,0)) ); // 160
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(.4L,0,0)) ); // 192
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(.5L,0,0)) ); // 224
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(.6L,0,0)) ); // 256
		++header_idx;
		assert( header_idx < 16 );
		m.insert( make_pair(header_idx, rgb_type(.7L,0,0)) ); // 320

		// Bad bitrate
		assert( m.end() == m.find(0x0F) );
		m.insert( make_pair(0x0F, ict(0xF3,0xEE,0xA5).convert<double,1>()) );
	}

	return m;
}

} // ns old_colourscheme
} // ns impl
} // ns mp3plot

