/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: spinner.h 1215 2009-04-25 12:47:38Z  $

#ifndef ONET_SPINNER_H
#define ONET_SPINNER_H

#include "mp3_config.h"

namespace net_outlyer {

// The spinner is currently a hack (well, actually, it works on a too low
// level for a C++ program :P)
// This was done this way mainly because it was quicker to prototype and
// write. Will be fixed sometime.

/*!
 * \brief Textual spinner
 * Creates a spinner in its own thread. The spinner is in the form "[-]", where
 * the dash will \em rotate.
 * When stopped it will be deleted from the screen.
 * It is meant to be non-blocking, but behaviour with a huge amount of steps
 * is unknown.
 * \todo FIXME: Implement at a higher level
 */
class spinner {
    public:
        spinner() : stopped(false) {}

        /*!
         * \brief Stops the spinner if needed
         * \see stop()
         */
        ~spinner();

        /*!
         * \brief Creates the spinner.
         * <em>Implementation details:</em> It spawns a new process that
         * will receive a notification on each step and update itself then.
         */
        void start();

        /*!
         * \copydoc operator++(int)
         * \deprecated operator++(int) or operator++() are preferred yet this
         * won't be removed
         */
        void step();

        /*!
         * \brief Stops the spinner
         * <em>Implementation details:</em> It stops the child process.
         * \note This is optional, as the destructor would call it anyway
         * \note It is safe to call stop() more than once
         */
        void stop();

        // TODO: When operator++ is defined with a return value
        // the spinner stops working; probably it's a problem with the
        // use of pipes, as when using the spinner in slower-stepping
        // contexts it works

        // Postfix operator
        /*!
         * \brief Spins the spinner
         * \pre The spinner is started and not stopped
         * The parent thread uses this to notify the child that it should spin.
         */
        void operator++(int dummyarg);

        // Prefix operator
        /*!
         * \copydoc operator++(int)
         */
        void operator++();
    private:
        //! Symbols printed to give the impression of a spinner
        static const char * SYMS;
        //! true if stop() has already been called
        bool stopped;
};

} // namespace net_outlyer

#endif // ONET_SPINNER_H
// vim:set ts=4 et ai:
