/*
 * Copyright (c) 2009, Toni Corvera. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
// $Id: algo.hxx 1086 2009-04-01 18:32:38Z  $

#ifndef ONET_ALGO_HXX
#define ONET_ALGO_HXX

#ifdef __GNUC__
#   define ONET_ALGO_HXX_UNUSED __attribute__((unused))
#else
#   define ONET_ALGO_HXX_UNUSED // Nothing
#endif

namespace net_outlyer {

/*!
 * \brief Predicate "less than" meant to act over maps' values instead of keys.
 * Usage:
 * \code
 * map<int, int> MyMap;
 * max_element(MyMap.begin(), MyMap.end(), second_is_less<map<int, int> >());
 * \endcode
 */
template<typename map_type> struct second_is_less {
    second_is_less() {
        ONET_ALGO_HXX_UNUSED void (*ct)(map_type&) = constraints;
    }

    bool operator()(typename map_type::value_type & a,
                    typename map_type::value_type & b) const {
        return a.second < b.second;
    }

    private:

    static void constraints(map_type &) {
        // Ensure the type has the expected typedefs...
        typedef typename map_type::value_type vt;
        typedef typename map_type::mapped_type mt;
        typedef typename map_type::key_type kt;
        // ... And they work as expected
        ONET_ALGO_HXX_UNUSED vt element;
        ONET_ALGO_HXX_UNUSED kt key = element.first;
        ONET_ALGO_HXX_UNUSED mt value = element.second;
    }
}; // struct second_is_less

} // ns net_outlyer

#endif // ONET_ALGO_HXX
// vim:set ts=4 et ai: //

