/*
 * Copyright (c) 2006, 2007, 2009 Toni Corvera. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

// $Id: named_file.hxx 1344 2009-06-22 01:11:09Z toni $

/*!
 * \file
 * \brief File class retaining file name.
 */
#ifndef ONET_NAMED_FILE_H
#define ONET_NAMED_FILE_H

#include <string>

namespace net_outlyer {

//! Classes and methods for file handling
namespace file {

/*!
 * \brief Abstract base class for files that store the filename.
 */
class named_file {
    public:
        /*!
         * \brief Obtains the filename.
         */
        const std::string & name() const { return name_; }

    protected:
        //! Default constructor
        explicit named_file(const std::string & name)
            : name_(name)
        {}

        //! Copy constructor
        named_file(const named_file & nf)
            : name_(nf.name_)
        {}

        /*!
         * \brief Equivalence operator.
         * \remarks Two named_file's are equivalent if the name is equal.
         */
        bool operator==(const named_file & nf) const {
            if (this == &nf) { return true; }
            return nf.name_ == name_;
        }
    private:
        //! The file name
        const std::string name_;
};

}

}

#endif // ONET_NAMED_FILE_H
// vim:set ts=4 et ai:

